Hugging Face Local Model Evals
huggingface/skills
Runs evaluations of Hugging Face Hub models on local hardware with inspect-ai or lighteval, and helps choose between vLLM, Transformers and accelerate backends.
Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill batch-triton-ascend-token-reorder -a claude-codeProject install by default; add -g for ~/.claude/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit batch-triton-ascend-token-reorder --agent claude-codeProject scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/batch-triton-ascend-token-reorder .claude/skills/batch-triton-ascend-token-reorder && rm -rf skills-srcUse ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.
Claude Code skills documentation · loads skills from .claude/skills/
Install the "batch-triton-ascend-token-reorder" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/batch-triton-ascend-token-reorder into .claude/skills/batch-triton-ascend-token-reorder/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "batch-triton-ascend-token-reorder", then confirm the skill loads.Claude Code copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$skill-installer install https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/batch-triton-ascend-token-reorderType this inside Codex. $skill-installer <name> installs a curated skill from openai/skills. The installer writes to $CODEX_HOME/skills (default ~/.codex/skills). Restart Codex if the skill does not show up.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill batch-triton-ascend-token-reorder -a codexProject install goes to .agents/skills/; add -g for ~/.codex/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit batch-triton-ascend-token-reorder --agent codexProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .agents/skills && cp -r skills-src/skills/batch-triton-ascend-token-reorder .agents/skills/batch-triton-ascend-token-reorder && rm -rf skills-srcUse ~/.agents/skills/ instead of .agents/skills for a personal install.
Codex skills documentation · loads skills from .agents/skills/
Install the "batch-triton-ascend-token-reorder" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/batch-triton-ascend-token-reorder into .agents/skills/batch-triton-ascend-token-reorder/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "batch-triton-ascend-token-reorder", then confirm the skill loads.Codex copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill batch-triton-ascend-token-reorder -a cursorProject install goes to .agents/skills/; add -g for ~/.cursor/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit batch-triton-ascend-token-reorder --agent cursorProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .cursor/skills && cp -r skills-src/skills/batch-triton-ascend-token-reorder .cursor/skills/batch-triton-ascend-token-reorder && rm -rf skills-srcUse ~/.cursor/skills/ instead of .cursor/skills for a personal install.
Cursor skills documentation · loads skills from .cursor/skills/, .agents/skills/, .claude/skills/, .codex/skills/
Install the "batch-triton-ascend-token-reorder" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/batch-triton-ascend-token-reorder into .cursor/skills/batch-triton-ascend-token-reorder/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "batch-triton-ascend-token-reorder", then confirm the skill loads.Cursor copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gemini skills install https://github.com/Krusty84/triton-ascend-agent-dev-kit.git --path skills/batch-triton-ascend-token-reorder--scope user (default) or --scope workspace; --path is the subfolder of the repo that holds the skill; --consent skips the security confirmation prompt.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill batch-triton-ascend-token-reorder -a gemini-cliProject install goes to .agents/skills/; add -g for ~/.gemini/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit batch-triton-ascend-token-reorder --agent gemini-cliProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .gemini/skills && cp -r skills-src/skills/batch-triton-ascend-token-reorder .gemini/skills/batch-triton-ascend-token-reorder && rm -rf skills-srcUse ~/.gemini/skills/ instead of .gemini/skills for a personal install, then run /skills reload.
Gemini CLI skills documentation · loads skills from .gemini/skills/, .agents/skills/
Install the "batch-triton-ascend-token-reorder" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/batch-triton-ascend-token-reorder into .gemini/skills/batch-triton-ascend-token-reorder/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "batch-triton-ascend-token-reorder", then confirm the skill loads.Gemini CLI copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit batch-triton-ascend-token-reorderInstalls for Copilot at project scope by default; add --scope user for a personal install. Preview a skill first with gh skill preview. Needs GitHub CLI 2.90.0 or later (public preview).
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill batch-triton-ascend-token-reorder -a github-copilotProject install goes to .agents/skills/; add -g for ~/.copilot/skills/.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .github/skills && cp -r skills-src/skills/batch-triton-ascend-token-reorder .github/skills/batch-triton-ascend-token-reorder && rm -rf skills-srcUse ~/.copilot/skills/ instead of .github/skills for a personal install. Commit .github/skills so cloud agent and code review can use it.
GitHub Copilot skills documentation · loads skills from .github/skills/, .claude/skills/, .agents/skills/
Install the "batch-triton-ascend-token-reorder" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/batch-triton-ascend-token-reorder into .github/skills/batch-triton-ascend-token-reorder/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "batch-triton-ascend-token-reorder", then confirm the skill loads.GitHub Copilot copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill batch-triton-ascend-token-reorder -a opencodeOpenCode documents no install command of its own. Project install goes to .agents/skills/; add -g for ~/.config/opencode/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit batch-triton-ascend-token-reorder --agent opencodeProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .opencode/skills && cp -r skills-src/skills/batch-triton-ascend-token-reorder .opencode/skills/batch-triton-ascend-token-reorder && rm -rf skills-srcUse ~/.config/opencode/skills/ instead of .opencode/skills for a personal install.
OpenCode skills documentation · loads skills from .opencode/skills/, .claude/skills/, .agents/skills/
Install the "batch-triton-ascend-token-reorder" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/batch-triton-ascend-token-reorder into .opencode/skills/batch-triton-ascend-token-reorder/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "batch-triton-ascend-token-reorder", then confirm the skill loads.OpenCode copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
batch-triton-ascend-token-reorderWrites a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.
The goal is implementing output[j] = input[indices[j]] on Ascend NPU without falling back to one program per token, which creates too many logical cores and scattered writes on GPU-style tiling. Input and output are treated as an S by D matrix and indices as a length-S integer vector; each program is assigned BLOCK_SIZE consecutive output rows, loads their indices as one vector, loops over the valid rows to load each indexed D-element source row, inserts it into a BLOCK_SIZE by D buffer in UB memory using extension.insert_slice, and stores the assembled tile with row and column masks.
Guardrails call for validating every selected index as within bounds before loading, computing the output row offset as row times D since omitting that multiplication overlaps rows, and sizing BLOCK_SIZE against the UB memory cost of the full tile plus a temporary row. D must be a legal compile-time tile size or padded with column masks. The pattern only removes scattered output writes; source reads stay random. Verification compares results against a plain input[indices] gather across permutations, repeated indices, a partial final block and invalid-index cases that must fail before the kernel launches.
5 steps, taken from the first numbered list in SKILL.md.
Read from SKILL.md and the folder at commit 4ab5ee7. It shows what the files ask for, not the result of running them.
Pre-approves nothing: there is no allowed-tools line, so your agent's usual permission prompts apply.
From allowed-tools in the SKILL.md frontmatter.
No scripts in the folder and no shell commands in SKILL.md (its code samples are python).
From the folder's file list and the shell code blocks in SKILL.md.
No URLs in SKILL.md.
From URLs in SKILL.md, links to its own repository left out.
Names no API keys, tokens, secrets or passwords.
From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.
Triton-Ascend Batch Token Reorder loads about 597 tokens when it runs. Until then it costs about 91 tokens; SKILL.md has 194 words of instructions outside code blocks.
Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.
The automated check found no risky patterns in SKILL.md.
Automated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.
The full file from Krusty84/triton-ascend-agent-dev-kit at commit 4ab5ee7, republished under its Apache-2.0 licence (© Krusty84). 194 words, ~597 tokens.
.claude/skills/batch-triton-ascend-token-reorder/SKILL.md (or your agent's skills folder).Gather several indexed token rows per program, assemble them in an on-chip buffer, and write one contiguous output tile.
import triton.language.extra.cann.extension as extension
rows = pid * BLOCK_SIZE + tl.arange(0, BLOCK_SIZE)
row_mask = rows < S
selected = tl.load(indices + rows, mask=row_mask, other=0)
tile = tl.zeros((BLOCK_SIZE, D), dtype=x_ptr.dtype.element_ty)
for i in range(0, BLOCK_SIZE):
if pid * BLOCK_SIZE + i < S:
source_row = extension.get_element(selected, (i,))
cols = tl.arange(0, D)
values = tl.load(x_ptr + source_row * D + cols)
tile = extension.insert_slice(
tile, values[None, :], (i, 0), (1, D), (1, 1)
)
cols = tl.arange(0, D)
out_offsets = rows[:, None] * D + cols[None, :]
tl.store(out_ptr + out_offsets, tile, mask=row_mask[:, None])Compare with input[indices] for permutations and repeated indices. Include a partial final block and invalid-index tests that must fail before kernel launch.
© Krusty84, Apache-2.0. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file
Just SKILL.md in skills/batch-triton-ascend-token-reorder of Krusty84/triton-ascend-agent-dev-kit.
Open the folder on GitHubat commit 4ab5ee7
Triton-Ascend Batch Token Reorder next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.
| Skill | Stars | Used in | Tokens | Auto-check | Licence | Repo updated |
|---|---|---|---|---|---|---|
| Triton-Ascend Batch Token Reorder this skillKrusty84/triton-ascend-agent-dev-kit | 106 | — | ~597 | Automated safety check: Pass | Apache-2.0 | |
| Hugging Face Local Model Evalshuggingface/skills | 11k | 2 repos | ~1.6k | Automated safety check: Pass | Apache-2.0 | |
| 0G Compute Network Guideinternet-court/internet-court-skill | 6.6k | 1 repos | ~1.9k | Automated safety check: Pass | Custom licence | |
| LLM Serving Capacity PlannerBBuf/AI-Infra-Auto-Driven-SKILLS | 938 | — | ~2.5k | Automated safety check: Pass | None | |
| Ascend Model Adapter for vLLMvllm-project/vllm-ascend | 2.9k | — | ~2.2k | Automated safety check: Pass | Apache-2.0 | |
| Graphsignalgraphsignal/graphsignal | 257 | — | ~6.3k | Automated safety check: Pass | Apache-2.0 |
huggingface/skills
Runs evaluations of Hugging Face Hub models on local hardware with inspect-ai or lighteval, and helps choose between vLLM, Transformers and accelerate backends.
internet-court/internet-court-skill
Guides building on the 0G Compute Network, a decentralized GPU marketplace for AI inference and fine-tuning, with SDK patterns and CLI commands.
BBuf/AI-Infra-Auto-Driven-SKILLS
Reads SGLang or vLLM startup logs to show where GPU memory went and estimates how many concurrent requests fit at common token lengths.
vllm-project/vllm-ascend
Adapts and debugs Hugging Face or local models to run on vLLM with Ascend NPU, validates them by serving, and delivers the result as one signed commit.
graphsignal/graphsignal
Profile AI inference workloads (vLLM, SGLang, TensorRT-LLM, PyTorch, any GPU application) with the Graphsignal profiler and read the results from its local /signals JSON endpoint.
BBuf/AI-Infra-Auto-Driven-SKILLS
Analyzes Torch Profiler traces from SGLang, vLLM and TensorRT-LLM servers into kernel attribution, overlap and fusion tables.
Krusty84/triton-ascend-agent-dev-kit
Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.
Krusty84/triton-ascend-agent-dev-kit
Builds Triton-Ascend kernels that pack sorted token assignments into fixed expert-capacity tensors, restore top-k outputs and compute router-weight gradients on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Guides building a FlashAttention-v2-style fused forward attention kernel for Triton-Ascend on Ascend NPU, with online softmax, causal staging and float32 accumulation.
Krusty84/triton-ascend-agent-dev-kit
Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.
Krusty84/triton-ascend-agent-dev-kit
Build Ascend-friendly MoE gather, scatter, and router-weight-gradient kernels with vector-core-sized grids, UB-aware row/column tiling, and CANN slice extensions.
Categories
Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering. The goal is implementing output[j] = input[indices[j]] on Ascend NPU without falling back to one program per token, which creates too many logical cores and scattered writes on GPU-style tiling.insert_slice, and stores the assembled tile with row and column masks.
Triton-Ascend Batch Token Reorder fits situations like: implementing a gather-by-index kernel for MoE token reordering on Ascend NPU; replacing a one-program-per-token GPU tiling pattern that creates too many logical cores on Ascend; writing a Triton-Ascend kernel that needs coalesced output stores despite random source reads.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill batch-triton-ascend-token-reorder -a claude-code`. Or copy the skill folder (skills/batch-triton-ascend-token-reorder in Krusty84/triton-ascend-agent-dev-kit) into .claude/skills/batch-triton-ascend-token-reorder in your project. Claude Code loads it when a task matches its description.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill batch-triton-ascend-token-reorder -a codex`. Or copy the skill folder (skills/batch-triton-ascend-token-reorder in Krusty84/triton-ascend-agent-dev-kit) into .agents/skills/batch-triton-ascend-token-reorder in your project. Codex loads it when a task matches its description.
Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill batch-triton-ascend-token-reorder -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/batch-triton-ascend-token-reorder, .gemini/skills/batch-triton-ascend-token-reorder, .github/skills/batch-triton-ascend-token-reorder and .opencode/skills/batch-triton-ascend-token-reorder in your project.
SKILL.md names no scripts, command-line tools or credentials: Triton-Ascend Batch Token Reorder is instructions for the agent only. Our summary lists: Triton-Ascend with the extension.insert_slice and extension.get_element APIs.
SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.
Our automated static check of SKILL.md found no risky patterns, such as piping downloads into a shell, reading credential files or hidden Unicode. It is not a guarantee. Review the folder before installing.
Triton-Ascend Batch Token Reorder is published under the Apache-2.0 licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.
About 597 tokens (SKILL.md is roughly 2.4k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.
Skills that share tags, products or a category with Triton-Ascend Batch Token Reorder: Hugging Face Local Model Evals (huggingface/skills, 11k stars), 0G Compute Network Guide (internet-court/internet-court-skill, 6.6k stars), LLM Serving Capacity Planner (BBuf/AI-Infra-Auto-Driven-SKILLS, 938 stars) and Ascend Model Adapter for vLLM (vllm-project/vllm-ascend, 2.9k stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.
Krusty84 (a GitHub user) maintains it in Krusty84/triton-ascend-agent-dev-kit, which has 106 GitHub stars. The repository holds 23 skills in this directory. The repository was last updated on August 15, 2026.
Source: Krusty84/triton-ascend-agent-dev-kit on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.